# coding: utf-8

"""
    Aron API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from openapi_client.configuration import Configuration


class ResponseDatasetSource(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'aws_role_arn': 'str',
        'bucket_name': 'str',
        'cluster_id': 'int',
        'cluster_name': 'str',
        'is_external': 'bool',
        'local_volume_config': 'OrmLocalVolumeConfig',
        'path': 'str',
        'type': 'str'
    }

    attribute_map = {
        'aws_role_arn': 'aws_role_arn',
        'bucket_name': 'bucket_name',
        'cluster_id': 'cluster_id',
        'cluster_name': 'cluster_name',
        'is_external': 'is_external',
        'local_volume_config': 'local_volume_config',
        'path': 'path',
        'type': 'type'
    }

    def __init__(self, aws_role_arn=None, bucket_name=None, cluster_id=None, cluster_name=None, is_external=None, local_volume_config=None, path=None, type=None, local_vars_configuration=None):  # noqa: E501
        """ResponseDatasetSource - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._aws_role_arn = None
        self._bucket_name = None
        self._cluster_id = None
        self._cluster_name = None
        self._is_external = None
        self._local_volume_config = None
        self._path = None
        self._type = None
        self.discriminator = None

        self.aws_role_arn = aws_role_arn
        self.bucket_name = bucket_name
        self.cluster_id = cluster_id
        self.cluster_name = cluster_name
        self.is_external = is_external
        if local_volume_config is not None:
            self.local_volume_config = local_volume_config
        self.path = path
        self.type = type

    @property
    def aws_role_arn(self):
        """Gets the aws_role_arn of this ResponseDatasetSource.  # noqa: E501


        :return: The aws_role_arn of this ResponseDatasetSource.  # noqa: E501
        :rtype: str
        """
        return self._aws_role_arn

    @aws_role_arn.setter
    def aws_role_arn(self, aws_role_arn):
        """Sets the aws_role_arn of this ResponseDatasetSource.


        :param aws_role_arn: The aws_role_arn of this ResponseDatasetSource.  # noqa: E501
        :type aws_role_arn: str
        """

        self._aws_role_arn = aws_role_arn

    @property
    def bucket_name(self):
        """Gets the bucket_name of this ResponseDatasetSource.  # noqa: E501


        :return: The bucket_name of this ResponseDatasetSource.  # noqa: E501
        :rtype: str
        """
        return self._bucket_name

    @bucket_name.setter
    def bucket_name(self, bucket_name):
        """Sets the bucket_name of this ResponseDatasetSource.


        :param bucket_name: The bucket_name of this ResponseDatasetSource.  # noqa: E501
        :type bucket_name: str
        """

        self._bucket_name = bucket_name

    @property
    def cluster_id(self):
        """Gets the cluster_id of this ResponseDatasetSource.  # noqa: E501


        :return: The cluster_id of this ResponseDatasetSource.  # noqa: E501
        :rtype: int
        """
        return self._cluster_id

    @cluster_id.setter
    def cluster_id(self, cluster_id):
        """Sets the cluster_id of this ResponseDatasetSource.


        :param cluster_id: The cluster_id of this ResponseDatasetSource.  # noqa: E501
        :type cluster_id: int
        """

        self._cluster_id = cluster_id

    @property
    def cluster_name(self):
        """Gets the cluster_name of this ResponseDatasetSource.  # noqa: E501


        :return: The cluster_name of this ResponseDatasetSource.  # noqa: E501
        :rtype: str
        """
        return self._cluster_name

    @cluster_name.setter
    def cluster_name(self, cluster_name):
        """Sets the cluster_name of this ResponseDatasetSource.


        :param cluster_name: The cluster_name of this ResponseDatasetSource.  # noqa: E501
        :type cluster_name: str
        """

        self._cluster_name = cluster_name

    @property
    def is_external(self):
        """Gets the is_external of this ResponseDatasetSource.  # noqa: E501


        :return: The is_external of this ResponseDatasetSource.  # noqa: E501
        :rtype: bool
        """
        return self._is_external

    @is_external.setter
    def is_external(self, is_external):
        """Sets the is_external of this ResponseDatasetSource.


        :param is_external: The is_external of this ResponseDatasetSource.  # noqa: E501
        :type is_external: bool
        """
        if self.local_vars_configuration.client_side_validation and is_external is None:  # noqa: E501
            raise ValueError("Invalid value for `is_external`, must not be `None`")  # noqa: E501

        self._is_external = is_external

    @property
    def local_volume_config(self):
        """Gets the local_volume_config of this ResponseDatasetSource.  # noqa: E501


        :return: The local_volume_config of this ResponseDatasetSource.  # noqa: E501
        :rtype: OrmLocalVolumeConfig
        """
        return self._local_volume_config

    @local_volume_config.setter
    def local_volume_config(self, local_volume_config):
        """Sets the local_volume_config of this ResponseDatasetSource.


        :param local_volume_config: The local_volume_config of this ResponseDatasetSource.  # noqa: E501
        :type local_volume_config: OrmLocalVolumeConfig
        """

        self._local_volume_config = local_volume_config

    @property
    def path(self):
        """Gets the path of this ResponseDatasetSource.  # noqa: E501


        :return: The path of this ResponseDatasetSource.  # noqa: E501
        :rtype: str
        """
        return self._path

    @path.setter
    def path(self, path):
        """Sets the path of this ResponseDatasetSource.


        :param path: The path of this ResponseDatasetSource.  # noqa: E501
        :type path: str
        """

        self._path = path

    @property
    def type(self):
        """Gets the type of this ResponseDatasetSource.  # noqa: E501


        :return: The type of this ResponseDatasetSource.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this ResponseDatasetSource.


        :param type: The type of this ResponseDatasetSource.  # noqa: E501
        :type type: str
        """
        if self.local_vars_configuration.client_side_validation and type is None:  # noqa: E501
            raise ValueError("Invalid value for `type`, must not be `None`")  # noqa: E501

        self._type = type

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ResponseDatasetSource):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ResponseDatasetSource):
            return True

        return self.to_dict() != other.to_dict()
