# coding: utf-8

"""
    Aron API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from openapi_client.configuration import Configuration


class S3DatasetCreateAPIPayload(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'aws_role_arn': 'str',
        'description': 'str',
        'is_public': 'bool',
        'is_version_enabled': 'bool',
        'name': 'str',
        's3_path': 'str',
        'version_s3_path': 'str'
    }

    attribute_map = {
        'aws_role_arn': 'aws_role_arn',
        'description': 'description',
        'is_public': 'is_public',
        'is_version_enabled': 'is_version_enabled',
        'name': 'name',
        's3_path': 's3_path',
        'version_s3_path': 'version_s3_path'
    }

    def __init__(self, aws_role_arn=None, description=None, is_public=None, is_version_enabled=None, name=None, s3_path=None, version_s3_path=None, local_vars_configuration=None):  # noqa: E501
        """S3DatasetCreateAPIPayload - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._aws_role_arn = None
        self._description = None
        self._is_public = None
        self._is_version_enabled = None
        self._name = None
        self._s3_path = None
        self._version_s3_path = None
        self.discriminator = None

        self.aws_role_arn = aws_role_arn
        self.description = description
        if is_public is not None:
            self.is_public = is_public
        if is_version_enabled is not None:
            self.is_version_enabled = is_version_enabled
        self.name = name
        self.s3_path = s3_path
        if version_s3_path is not None:
            self.version_s3_path = version_s3_path

    @property
    def aws_role_arn(self):
        """Gets the aws_role_arn of this S3DatasetCreateAPIPayload.  # noqa: E501


        :return: The aws_role_arn of this S3DatasetCreateAPIPayload.  # noqa: E501
        :rtype: str
        """
        return self._aws_role_arn

    @aws_role_arn.setter
    def aws_role_arn(self, aws_role_arn):
        """Sets the aws_role_arn of this S3DatasetCreateAPIPayload.


        :param aws_role_arn: The aws_role_arn of this S3DatasetCreateAPIPayload.  # noqa: E501
        :type aws_role_arn: str
        """

        self._aws_role_arn = aws_role_arn

    @property
    def description(self):
        """Gets the description of this S3DatasetCreateAPIPayload.  # noqa: E501


        :return: The description of this S3DatasetCreateAPIPayload.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this S3DatasetCreateAPIPayload.


        :param description: The description of this S3DatasetCreateAPIPayload.  # noqa: E501
        :type description: str
        """

        self._description = description

    @property
    def is_public(self):
        """Gets the is_public of this S3DatasetCreateAPIPayload.  # noqa: E501


        :return: The is_public of this S3DatasetCreateAPIPayload.  # noqa: E501
        :rtype: bool
        """
        return self._is_public

    @is_public.setter
    def is_public(self, is_public):
        """Sets the is_public of this S3DatasetCreateAPIPayload.


        :param is_public: The is_public of this S3DatasetCreateAPIPayload.  # noqa: E501
        :type is_public: bool
        """

        self._is_public = is_public

    @property
    def is_version_enabled(self):
        """Gets the is_version_enabled of this S3DatasetCreateAPIPayload.  # noqa: E501


        :return: The is_version_enabled of this S3DatasetCreateAPIPayload.  # noqa: E501
        :rtype: bool
        """
        return self._is_version_enabled

    @is_version_enabled.setter
    def is_version_enabled(self, is_version_enabled):
        """Sets the is_version_enabled of this S3DatasetCreateAPIPayload.


        :param is_version_enabled: The is_version_enabled of this S3DatasetCreateAPIPayload.  # noqa: E501
        :type is_version_enabled: bool
        """

        self._is_version_enabled = is_version_enabled

    @property
    def name(self):
        """Gets the name of this S3DatasetCreateAPIPayload.  # noqa: E501


        :return: The name of this S3DatasetCreateAPIPayload.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this S3DatasetCreateAPIPayload.


        :param name: The name of this S3DatasetCreateAPIPayload.  # noqa: E501
        :type name: str
        """
        if self.local_vars_configuration.client_side_validation and name is None:  # noqa: E501
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def s3_path(self):
        """Gets the s3_path of this S3DatasetCreateAPIPayload.  # noqa: E501


        :return: The s3_path of this S3DatasetCreateAPIPayload.  # noqa: E501
        :rtype: str
        """
        return self._s3_path

    @s3_path.setter
    def s3_path(self, s3_path):
        """Sets the s3_path of this S3DatasetCreateAPIPayload.


        :param s3_path: The s3_path of this S3DatasetCreateAPIPayload.  # noqa: E501
        :type s3_path: str
        """
        if self.local_vars_configuration.client_side_validation and s3_path is None:  # noqa: E501
            raise ValueError("Invalid value for `s3_path`, must not be `None`")  # noqa: E501

        self._s3_path = s3_path

    @property
    def version_s3_path(self):
        """Gets the version_s3_path of this S3DatasetCreateAPIPayload.  # noqa: E501


        :return: The version_s3_path of this S3DatasetCreateAPIPayload.  # noqa: E501
        :rtype: str
        """
        return self._version_s3_path

    @version_s3_path.setter
    def version_s3_path(self, version_s3_path):
        """Sets the version_s3_path of this S3DatasetCreateAPIPayload.


        :param version_s3_path: The version_s3_path of this S3DatasetCreateAPIPayload.  # noqa: E501
        :type version_s3_path: str
        """

        self._version_s3_path = version_s3_path

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, S3DatasetCreateAPIPayload):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, S3DatasetCreateAPIPayload):
            return True

        return self.to_dict() != other.to_dict()
